@@ -3,7 +3,7 @@ from pywayland.server import Display, Signal
 
 from wlroots import Ptr, PtrHasData, ffi, lib
 
-from .surface import Surface
+from .compositor import Surface
 
 
 class IdleInhibitorManagerV1(Ptr):
